All of lore.kernel.org
 help / color / mirror / Atom feed
From: Benjamin Gaignard <benjamin.gaignard@collabora.com>
To: mchehab@kernel.org, tfiga@chromium.org, m.szyprowski@samsung.com,
	ming.qian@nxp.com, ezequiel@vanguardiasur.com.ar,
	p.zabel@pengutronix.de, gregkh@linuxfoundation.org,
	hverkuil-cisco@xs4all.nl, nicolas.dufresne@collabora.com
Cc: linux-media@vger.kernel.org, linux-kernel@vger.kernel.org,
	linux-arm-kernel@lists.infradead.org,
	linux-mediatek@lists.infradead.org,
	linux-arm-msm@vger.kernel.org,
	linux-rockchip@lists.infradead.org,
	linux-staging@lists.linux.dev, kernel@collabora.com,
	Benjamin Gaignard <benjamin.gaignard@collabora.com>
Subject: [PATCH v11 43/56] media: videobuf2: Be more flexible on the number of queue stored buffers
Date: Thu, 12 Oct 2023 13:46:29 +0200	[thread overview]
Message-ID: <20231012114642.19040-44-benjamin.gaignard@collabora.com> (raw)
In-Reply-To: <20231012114642.19040-1-benjamin.gaignard@collabora.com>

Add 'max_num_buffers' field in vb2_queue struct to let drivers decide
how many buffers could be stored in a queue.
This require 'bufs' array to be allocated at queue init time and freed
when releasing the queue.
By default VB2_MAX_FRAME remains the limit.

Signed-off-by: Benjamin Gaignard <benjamin.gaignard@collabora.com>
Signed-off-by: Hans Verkuil <hverkuil-cisco@xs4all.nl>Signed-off-by: Hans Verkuil <hverkuil-cisco@xs4all.nl>
---
 .../media/common/videobuf2/videobuf2-core.c   | 42 ++++++++++++++-----
 .../media/common/videobuf2/videobuf2-v4l2.c   |  6 +--
 include/media/videobuf2-core.h                |  4 +-
 3 files changed, 38 insertions(+), 14 deletions(-)

diff --git a/drivers/media/common/videobuf2/videobuf2-v4l2.c b/drivers/media/common/videobuf2/videobuf2-v4l2.c
index daa07f62c219..799dd43b4aa9 100644
--- a/drivers/media/common/videobuf2/videobuf2-v4l2.c
+++ b/drivers/media/common/videobuf2/videobuf2-v4l2.c
@@ -628,7 +628,7 @@ struct vb2_buffer *vb2_find_buffer(struct vb2_queue *q, u64 timestamp)
 	 * This loop doesn't scale if there is a really large number of buffers.
 	 * Maybe something more efficient will be needed in this case.
 	 */
-	for (i = 0; i < vb2_get_num_buffers(q); i++) {
+	for (i = 0; i < q->max_num_buffers; i++) {
 		vb2 = vb2_get_buffer(q, i);
 
 		if (!vb2)
@@ -1143,7 +1143,7 @@ int _vb2_fop_release(struct file *file, struct mutex *lock)
 
 	if (lock)
 		mutex_lock(lock);
-	if (file->private_data == vdev->queue->owner) {
+	if (!vdev->queue->owner || file->private_data == vdev->queue->owner) {
 		vb2_queue_release(vdev->queue);
 		vdev->queue->owner = NULL;
 	}
@@ -1271,7 +1271,7 @@ void vb2_video_unregister_device(struct video_device *vdev)
 	 */
 	get_device(&vdev->dev);
 	video_unregister_device(vdev);
-	if (vdev->queue && vdev->queue->owner) {
+	if (vdev->queue) {
 		struct mutex *lock = vdev->queue->lock ?
 			vdev->queue->lock : vdev->lock;
 
diff --git a/include/media/videobuf2-core.h b/include/media/videobuf2-core.h
index 8f9d9e4af5b1..cf276bda5924 100644
--- a/include/media/videobuf2-core.h
+++ b/include/media/videobuf2-core.h
@@ -558,6 +558,7 @@ struct vb2_buf_ops {
  * @dma_dir:	DMA mapping direction.
  * @bufs:	videobuf2 buffer structures
  * @num_buffers: number of allocated/used buffers
+ * @max_num_buffers: upper limit of number of allocated/used buffers
  * @queued_list: list of buffers currently queued from userspace
  * @queued_count: number of buffers queued and ready for streaming.
  * @owned_by_drv_count: number of buffers owned by the driver
@@ -619,8 +620,9 @@ struct vb2_queue {
 	struct mutex			mmap_lock;
 	unsigned int			memory;
 	enum dma_data_direction		dma_dir;
-	struct vb2_buffer		*bufs[VB2_MAX_FRAME];
+	struct vb2_buffer		**bufs;
 	unsigned int			num_buffers;
+	unsigned int			max_num_buffers;
 
 	struct list_head		queued_list;
 	unsigned int			queued_count;
diff --git a/drivers/media/common/videobuf2/videobuf2-v4l2.c b/drivers/media/common/videobuf2/videobuf2-v4l2.c
index daa07f62c219..799dd43b4aa9 100644
--- a/drivers/media/common/videobuf2/videobuf2-v4l2.c
+++ b/drivers/media/common/videobuf2/videobuf2-v4l2.c
@@ -628,7 +628,7 @@ struct vb2_buffer *vb2_find_buffer(struct vb2_queue *q, u64 timestamp)
 	 * This loop doesn't scale if there is a really large number of buffers.
 	 * Maybe something more efficient will be needed in this case.
 	 */
-	for (i = 0; i < vb2_get_num_buffers(q); i++) {
+	for (i = 0; i < q->max_num_buffers; i++) {
 		vb2 = vb2_get_buffer(q, i);
 
 		if (!vb2)
@@ -1143,7 +1143,7 @@ int _vb2_fop_release(struct file *file, struct mutex *lock)
 
 	if (lock)
 		mutex_lock(lock);
-	if (file->private_data == vdev->queue->owner) {
+	if (!vdev->queue->owner || file->private_data == vdev->queue->owner) {
 		vb2_queue_release(vdev->queue);
 		vdev->queue->owner = NULL;
 	}
@@ -1271,7 +1271,7 @@ void vb2_video_unregister_device(struct video_device *vdev)
 	 */
 	get_device(&vdev->dev);
 	video_unregister_device(vdev);
-	if (vdev->queue && vdev->queue->owner) {
+	if (vdev->queue) {
 		struct mutex *lock = vdev->queue->lock ?
 			vdev->queue->lock : vdev->lock;
 
diff --git a/include/media/videobuf2-core.h b/include/media/videobuf2-core.h
index 8f9d9e4af5b1..cf276bda5924 100644
--- a/include/media/videobuf2-core.h
+++ b/include/media/videobuf2-core.h
@@ -558,6 +558,7 @@ struct vb2_buf_ops {
  * @dma_dir:	DMA mapping direction.
  * @bufs:	videobuf2 buffer structures
  * @num_buffers: number of allocated/used buffers
+ * @max_num_buffers: upper limit of number of allocated/used buffers
  * @queued_list: list of buffers currently queued from userspace
  * @queued_count: number of buffers queued and ready for streaming.
  * @owned_by_drv_count: number of buffers owned by the driver
@@ -619,8 +620,9 @@ struct vb2_queue {
 	struct mutex			mmap_lock;
 	unsigned int			memory;
 	enum dma_data_direction		dma_dir;
-	struct vb2_buffer		*bufs[VB2_MAX_FRAME];
+	struct vb2_buffer		**bufs;
 	unsigned int			num_buffers;
+	unsigned int			max_num_buffers;
 
 	struct list_head		queued_list;
 	unsigned int			queued_count;
diff --git a/drivers/media/common/videobuf2/videobuf2-v4l2.c b/drivers/media/common/videobuf2/videobuf2-v4l2.c
index daa07f62c219..799dd43b4aa9 100644
--- a/drivers/media/common/videobuf2/videobuf2-v4l2.c
+++ b/drivers/media/common/videobuf2/videobuf2-v4l2.c
@@ -628,7 +628,7 @@ struct vb2_buffer *vb2_find_buffer(struct vb2_queue *q, u64 timestamp)
 	 * This loop doesn't scale if there is a really large number of buffers.
 	 * Maybe something more efficient will be needed in this case.
 	 */
-	for (i = 0; i < vb2_get_num_buffers(q); i++) {
+	for (i = 0; i < q->max_num_buffers; i++) {
 		vb2 = vb2_get_buffer(q, i);
 
 		if (!vb2)
@@ -1143,7 +1143,7 @@ int _vb2_fop_release(struct file *file, struct mutex *lock)
 
 	if (lock)
 		mutex_lock(lock);
-	if (file->private_data == vdev->queue->owner) {
+	if (!vdev->queue->owner || file->private_data == vdev->queue->owner) {
 		vb2_queue_release(vdev->queue);
 		vdev->queue->owner = NULL;
 	}
@@ -1271,7 +1271,7 @@ void vb2_video_unregister_device(struct video_device *vdev)
 	 */
 	get_device(&vdev->dev);
 	video_unregister_device(vdev);
-	if (vdev->queue && vdev->queue->owner) {
+	if (vdev->queue) {
 		struct mutex *lock = vdev->queue->lock ?
 			vdev->queue->lock : vdev->lock;
 
diff --git a/include/media/videobuf2-core.h b/include/media/videobuf2-core.h
index 8f9d9e4af5b1..cf276bda5924 100644
--- a/include/media/videobuf2-core.h
+++ b/include/media/videobuf2-core.h
@@ -558,6 +558,7 @@ struct vb2_buf_ops {
  * @dma_dir:	DMA mapping direction.
  * @bufs:	videobuf2 buffer structures
  * @num_buffers: number of allocated/used buffers
+ * @max_num_buffers: upper limit of number of allocated/used buffers
  * @queued_list: list of buffers currently queued from userspace
  * @queued_count: number of buffers queued and ready for streaming.
  * @owned_by_drv_count: number of buffers owned by the driver
@@ -619,8 +620,9 @@ struct vb2_queue {
 	struct mutex			mmap_lock;
 	unsigned int			memory;
 	enum dma_data_direction		dma_dir;
-	struct vb2_buffer		*bufs[VB2_MAX_FRAME];
+	struct vb2_buffer		**bufs;
 	unsigned int			num_buffers;
+	unsigned int			max_num_buffers;
 
 	struct list_head		queued_list;
 	unsigned int			queued_count;
diff --git a/drivers/media/common/videobuf2/videobuf2-core.c b/drivers/media/common/videobuf2/videobuf2-core.c
index c427aca285e3..eff4fe9c6f63 100644
--- a/drivers/media/common/videobuf2/videobuf2-core.c
+++ b/drivers/media/common/videobuf2/videobuf2-core.c
@@ -416,7 +416,7 @@ static void init_buffer_cache_hints(struct vb2_queue *q, struct vb2_buffer *vb)
  */
 static void vb2_queue_add_buffer(struct vb2_queue *q, struct vb2_buffer *vb, unsigned int index)
 {
-	WARN_ON(index >= VB2_MAX_FRAME || q->bufs[index]);
+	WARN_ON(index >= q->max_num_buffers || q->bufs[index]);
 
 	q->bufs[index] = vb;
 	vb->index = index;
@@ -450,9 +450,9 @@ static int __vb2_queue_alloc(struct vb2_queue *q, enum vb2_memory memory,
 	struct vb2_buffer *vb;
 	int ret;
 
 	/* Ensure that q->num_buffers+num_buffers is below VB2_MAX_FRAME */
 	num_buffers = min_t(unsigned int, num_buffers,
-			    VB2_MAX_FRAME - q->num_buffers);
+			    q->max_num_buffers - q->num_buffers);
 
 	for (buffer = 0; buffer < num_buffers; ++buffer) {
 		/* Allocate vb2 buffer structures */
@@ -816,7 +816,7 @@ int vb2_core_reqbufs(struct vb2_queue *q, enum vb2_memory memory,
 	unsigned plane_sizes[VB2_MAX_PLANES] = { };
 	bool non_coherent_mem = flags & V4L2_MEMORY_FLAG_NON_COHERENT;
 	unsigned int i;
-	int ret;
+	int ret = 0;
 
 	if (q->streaming) {
 		dprintk(q, 1, "streaming active\n");
@@ -860,17 +860,22 @@ int vb2_core_reqbufs(struct vb2_queue *q, enum vb2_memory memory,
 	/*
 	 * Make sure the requested values and current defaults are sane.
 	 */
-	WARN_ON(q->min_buffers_needed > VB2_MAX_FRAME);
 	num_buffers = max_t(unsigned int, *count, q->min_buffers_needed);
-	num_buffers = min_t(unsigned int, num_buffers, VB2_MAX_FRAME);
+	num_buffers = min_t(unsigned int, num_buffers, q->max_num_buffers);
 	memset(q->alloc_devs, 0, sizeof(q->alloc_devs));
 	/*
 	 * Set this now to ensure that drivers see the correct q->memory value
 	 * in the queue_setup op.
 	 */
 	mutex_lock(&q->mmap_lock);
+	if (!q->bufs)
+		q->bufs = kcalloc(q->max_num_buffers, sizeof(*q->bufs), GFP_KERNEL);
+	if (!q->bufs)
+		ret = -ENOMEM;
 	q->memory = memory;
 	mutex_unlock(&q->mmap_lock);
+	if (ret)
+		return ret;
 	set_queue_coherency(q, non_coherent_mem);
 
 	/*
@@ -979,7 +984,7 @@ int vb2_core_create_bufs(struct vb2_queue *q, enum vb2_memory memory,
 	bool no_previous_buffers = !q_num_bufs;
 	int ret = 0;
 
-	if (q_num_bufs == VB2_MAX_FRAME) {
+	if (q->num_buffers == q->max_num_buffers) {
 		dprintk(q, 1, "maximum number of buffers already allocated\n");
 		return -ENOBUFS;
 	}
@@ -996,7 +1001,13 @@ int vb2_core_create_bufs(struct vb2_queue *q, enum vb2_memory memory,
 		 */
 		mutex_lock(&q->mmap_lock);
 		q->memory = memory;
+		if (!q->bufs)
+			q->bufs = kcalloc(q->max_num_buffers, sizeof(*q->bufs), GFP_KERNEL);
+		if (!q->bufs)
+			ret = -ENOMEM;
 		mutex_unlock(&q->mmap_lock);
+		if (ret)
+			return ret;
 		q->waiting_for_buffers = !q->is_output;
 		set_queue_coherency(q, non_coherent_mem);
 	} else {
@@ -1008,7 +1019,7 @@ int vb2_core_create_bufs(struct vb2_queue *q, enum vb2_memory memory,
 			return -EINVAL;
 	}
 
-	num_buffers = min(*count, VB2_MAX_FRAME - q_num_bufs);
+	num_buffers = min(*count, q->max_num_buffers - q_num_bufs);
 
 	if (requested_planes && requested_sizes) {
 		num_planes = requested_planes;
@@ -2466,6 +2477,12 @@ int vb2_core_queue_init(struct vb2_queue *q)
 	/*
 	 * Sanity check
 	 */
+	if (!q->max_num_buffers)
+		q->max_num_buffers = VB2_MAX_FRAME;
+
+	/* The maximum is limited by offset cookie encoding pattern */
+	q->max_num_buffers = min_t(unsigned int, q->max_num_buffers, MAX_BUFFER_INDEX);
+
 	if (WARN_ON(!q)			  ||
 	    WARN_ON(!q->ops)		  ||
 	    WARN_ON(!q->mem_ops)	  ||
@@ -2475,6 +2492,10 @@ int vb2_core_queue_init(struct vb2_queue *q)
 	    WARN_ON(!q->ops->buf_queue))
 		return -EINVAL;
 
+	if (WARN_ON(q->max_num_buffers > MAX_BUFFER_INDEX) ||
+	    WARN_ON(q->min_buffers_needed > q->max_num_buffers))
+		return -EINVAL;
+
 	if (WARN_ON(q->requires_requests && !q->supports_requests))
 		return -EINVAL;
 
@@ -2520,8 +2541,9 @@ void vb2_core_queue_release(struct vb2_queue *q)
 	__vb2_cleanup_fileio(q);
 	__vb2_queue_cancel(q);
 	mutex_lock(&q->mmap_lock);
-	__vb2_queue_free(q, vb2_get_num_buffers(q));
-	q->num_buffers = 0;
+	__vb2_queue_free(q, q->max_num_buffers);
+	kfree(q->bufs);
+	q->bufs = NULL;
 	mutex_unlock(&q->mmap_lock);
 }
 EXPORT_SYMBOL_GPL(vb2_core_queue_release);
@@ -450,9 +450,9 @@ static int __vb2_queue_alloc(struct vb2_queue *q, enum vb2_memory memory,
 	int ret;
 
-	/* Ensure that q->num_buffers+num_buffers is below VB2_MAX_FRAME */
+	/* Ensure that the number of already queue + num_buffers is below q->max_num_buffers */
 	num_buffers = min_t(unsigned int, num_buffers,
-- 
2.39.2


WARNING: multiple messages have this Message-ID (diff)
From: Benjamin Gaignard <benjamin.gaignard@collabora.com>
To: mchehab@kernel.org, tfiga@chromium.org, m.szyprowski@samsung.com,
	ming.qian@nxp.com, ezequiel@vanguardiasur.com.ar,
	p.zabel@pengutronix.de, gregkh@linuxfoundation.org,
	hverkuil-cisco@xs4all.nl, nicolas.dufresne@collabora.com
Cc: linux-media@vger.kernel.org, linux-kernel@vger.kernel.org,
	linux-arm-kernel@lists.infradead.org,
	linux-mediatek@lists.infradead.org,
	linux-arm-msm@vger.kernel.org,
	linux-rockchip@lists.infradead.org,
	linux-staging@lists.linux.dev, kernel@collabora.com,
	Benjamin Gaignard <benjamin.gaignard@collabora.com>
Subject: [PATCH v11 43/56] media: videobuf2: Be more flexible on the number of queue stored buffers
Date: Thu, 12 Oct 2023 13:46:29 +0200	[thread overview]
Message-ID: <20231012114642.19040-44-benjamin.gaignard@collabora.com> (raw)
In-Reply-To: <20231012114642.19040-1-benjamin.gaignard@collabora.com>

Add 'max_num_buffers' field in vb2_queue struct to let drivers decide
how many buffers could be stored in a queue.
This require 'bufs' array to be allocated at queue init time and freed
when releasing the queue.
By default VB2_MAX_FRAME remains the limit.

Signed-off-by: Benjamin Gaignard <benjamin.gaignard@collabora.com>
Signed-off-by: Hans Verkuil <hverkuil-cisco@xs4all.nl>Signed-off-by: Hans Verkuil <hverkuil-cisco@xs4all.nl>
---
 .../media/common/videobuf2/videobuf2-core.c   | 42 ++++++++++++++-----
 .../media/common/videobuf2/videobuf2-v4l2.c   |  6 +--
 include/media/videobuf2-core.h                |  4 +-
 3 files changed, 38 insertions(+), 14 deletions(-)

diff --git a/drivers/media/common/videobuf2/videobuf2-core.c b/drivers/media/common/videobuf2/videobuf2-core.c
index c427aca285e3..eff4fe9c6f63 100644
--- a/drivers/media/common/videobuf2/videobuf2-core.c
+++ b/drivers/media/common/videobuf2/videobuf2-core.c
@@ -416,7 +416,7 @@ static void init_buffer_cache_hints(struct vb2_queue *q, struct vb2_buffer *vb)
  */
 static void vb2_queue_add_buffer(struct vb2_queue *q, struct vb2_buffer *vb, unsigned int index)
 {
-	WARN_ON(index >= VB2_MAX_FRAME || q->bufs[index]);
+	WARN_ON(index >= q->max_num_buffers || q->bufs[index]);
 
 	q->bufs[index] = vb;
 	vb->index = index;
@@ -450,9 +450,9 @@ static int __vb2_queue_alloc(struct vb2_queue *q, enum vb2_memory memory,
 	struct vb2_buffer *vb;
 	int ret;
 
 	/* Ensure that q->num_buffers+num_buffers is below VB2_MAX_FRAME */
 	num_buffers = min_t(unsigned int, num_buffers,
-			    VB2_MAX_FRAME - q->num_buffers);
+			    q->max_num_buffers - q->num_buffers);
 
 	for (buffer = 0; buffer < num_buffers; ++buffer) {
 		/* Allocate vb2 buffer structures */
@@ -816,7 +816,7 @@ int vb2_core_reqbufs(struct vb2_queue *q, enum vb2_memory memory,
 	unsigned plane_sizes[VB2_MAX_PLANES] = { };
 	bool non_coherent_mem = flags & V4L2_MEMORY_FLAG_NON_COHERENT;
 	unsigned int i;
-	int ret;
+	int ret = 0;
 
 	if (q->streaming) {
 		dprintk(q, 1, "streaming active\n");
@@ -860,17 +860,22 @@ int vb2_core_reqbufs(struct vb2_queue *q, enum vb2_memory memory,
 	/*
 	 * Make sure the requested values and current defaults are sane.
 	 */
-	WARN_ON(q->min_buffers_needed > VB2_MAX_FRAME);
 	num_buffers = max_t(unsigned int, *count, q->min_buffers_needed);
-	num_buffers = min_t(unsigned int, num_buffers, VB2_MAX_FRAME);
+	num_buffers = min_t(unsigned int, num_buffers, q->max_num_buffers);
 	memset(q->alloc_devs, 0, sizeof(q->alloc_devs));
 	/*
 	 * Set this now to ensure that drivers see the correct q->memory value
 	 * in the queue_setup op.
 	 */
 	mutex_lock(&q->mmap_lock);
+	if (!q->bufs)
+		q->bufs = kcalloc(q->max_num_buffers, sizeof(*q->bufs), GFP_KERNEL);
+	if (!q->bufs)
+		ret = -ENOMEM;
 	q->memory = memory;
 	mutex_unlock(&q->mmap_lock);
+	if (ret)
+		return ret;
 	set_queue_coherency(q, non_coherent_mem);
 
 	/*
@@ -979,7 +984,7 @@ int vb2_core_create_bufs(struct vb2_queue *q, enum vb2_memory memory,
 	bool no_previous_buffers = !q_num_bufs;
 	int ret = 0;
 
-	if (q_num_bufs == VB2_MAX_FRAME) {
+	if (q->num_buffers == q->max_num_buffers) {
 		dprintk(q, 1, "maximum number of buffers already allocated\n");
 		return -ENOBUFS;
 	}
@@ -996,7 +1001,13 @@ int vb2_core_create_bufs(struct vb2_queue *q, enum vb2_memory memory,
 		 */
 		mutex_lock(&q->mmap_lock);
 		q->memory = memory;
+		if (!q->bufs)
+			q->bufs = kcalloc(q->max_num_buffers, sizeof(*q->bufs), GFP_KERNEL);
+		if (!q->bufs)
+			ret = -ENOMEM;
 		mutex_unlock(&q->mmap_lock);
+		if (ret)
+			return ret;
 		q->waiting_for_buffers = !q->is_output;
 		set_queue_coherency(q, non_coherent_mem);
 	} else {
@@ -1008,7 +1019,7 @@ int vb2_core_create_bufs(struct vb2_queue *q, enum vb2_memory memory,
 			return -EINVAL;
 	}
 
-	num_buffers = min(*count, VB2_MAX_FRAME - q_num_bufs);
+	num_buffers = min(*count, q->max_num_buffers - q_num_bufs);
 
 	if (requested_planes && requested_sizes) {
 		num_planes = requested_planes;
@@ -2466,6 +2477,12 @@ int vb2_core_queue_init(struct vb2_queue *q)
 	/*
 	 * Sanity check
 	 */
+	if (!q->max_num_buffers)
+		q->max_num_buffers = VB2_MAX_FRAME;
+
+	/* The maximum is limited by offset cookie encoding pattern */
+	q->max_num_buffers = min_t(unsigned int, q->max_num_buffers, MAX_BUFFER_INDEX);
+
 	if (WARN_ON(!q)			  ||
 	    WARN_ON(!q->ops)		  ||
 	    WARN_ON(!q->mem_ops)	  ||
@@ -2475,6 +2492,10 @@ int vb2_core_queue_init(struct vb2_queue *q)
 	    WARN_ON(!q->ops->buf_queue))
 		return -EINVAL;
 
+	if (WARN_ON(q->max_num_buffers > MAX_BUFFER_INDEX) ||
+	    WARN_ON(q->min_buffers_needed > q->max_num_buffers))
+		return -EINVAL;
+
 	if (WARN_ON(q->requires_requests && !q->supports_requests))
 		return -EINVAL;
 
@@ -2520,8 +2541,9 @@ void vb2_core_queue_release(struct vb2_queue *q)
 	__vb2_cleanup_fileio(q);
 	__vb2_queue_cancel(q);
 	mutex_lock(&q->mmap_lock);
-	__vb2_queue_free(q, vb2_get_num_buffers(q));
-	q->num_buffers = 0;
+	__vb2_queue_free(q, q->max_num_buffers);
+	kfree(q->bufs);
+	q->bufs = NULL;
 	mutex_unlock(&q->mmap_lock);
 }
 EXPORT_SYMBOL_GPL(vb2_core_queue_release);
@@ -450,9 +450,9 @@ static int __vb2_queue_alloc(struct vb2_queue *q, enum vb2_memory memory,
 	int ret;
 
-	/* Ensure that q->num_buffers+num_buffers is below VB2_MAX_FRAME */
+	/* Ensure that the number of already queue + num_buffers is below q->max_num_buffers */
 	num_buffers = min_t(unsigned int, num_buffers,
-- 
2.39.2


_______________________________________________
linux-arm-kernel mailing list
linux-arm-kernel@lists.infradead.org
http://lists.infradead.org/mailman/listinfo/linux-arm-kernel

WARNING: multiple messages have this Message-ID (diff)
From: Benjamin Gaignard <benjamin.gaignard@collabora.com>
To: mchehab@kernel.org, tfiga@chromium.org, m.szyprowski@samsung.com,
	ming.qian@nxp.com, ezequiel@vanguardiasur.com.ar,
	p.zabel@pengutronix.de, gregkh@linuxfoundation.org,
	hverkuil-cisco@xs4all.nl, nicolas.dufresne@collabora.com
Cc: linux-media@vger.kernel.org, linux-kernel@vger.kernel.org,
	linux-arm-kernel@lists.infradead.org,
	linux-mediatek@lists.infradead.org,
	linux-arm-msm@vger.kernel.org,
	linux-rockchip@lists.infradead.org,
	linux-staging@lists.linux.dev, kernel@collabora.com,
	Benjamin Gaignard <benjamin.gaignard@collabora.com>
Subject: [PATCH v11 43/56] media: videobuf2: Be more flexible on the number of queue stored buffers
Date: Thu, 12 Oct 2023 13:46:29 +0200	[thread overview]
Message-ID: <20231012114642.19040-44-benjamin.gaignard@collabora.com> (raw)
In-Reply-To: <20231012114642.19040-1-benjamin.gaignard@collabora.com>

Add 'max_num_buffers' field in vb2_queue struct to let drivers decide
how many buffers could be stored in a queue.
This require 'bufs' array to be allocated at queue init time and freed
when releasing the queue.
By default VB2_MAX_FRAME remains the limit.

Signed-off-by: Benjamin Gaignard <benjamin.gaignard@collabora.com>
Signed-off-by: Hans Verkuil <hverkuil-cisco@xs4all.nl>Signed-off-by: Hans Verkuil <hverkuil-cisco@xs4all.nl>
---
 .../media/common/videobuf2/videobuf2-core.c   | 42 ++++++++++++++-----
 .../media/common/videobuf2/videobuf2-v4l2.c   |  6 +--
 include/media/videobuf2-core.h                |  4 +-
 3 files changed, 38 insertions(+), 14 deletions(-)

diff --git a/drivers/media/common/videobuf2/videobuf2-core.c b/drivers/media/common/videobuf2/videobuf2-core.c
index c427aca285e3..eff4fe9c6f63 100644
--- a/drivers/media/common/videobuf2/videobuf2-core.c
+++ b/drivers/media/common/videobuf2/videobuf2-core.c
@@ -416,7 +416,7 @@ static void init_buffer_cache_hints(struct vb2_queue *q, struct vb2_buffer *vb)
  */
 static void vb2_queue_add_buffer(struct vb2_queue *q, struct vb2_buffer *vb, unsigned int index)
 {
-	WARN_ON(index >= VB2_MAX_FRAME || q->bufs[index]);
+	WARN_ON(index >= q->max_num_buffers || q->bufs[index]);
 
 	q->bufs[index] = vb;
 	vb->index = index;
@@ -450,9 +450,9 @@ static int __vb2_queue_alloc(struct vb2_queue *q, enum vb2_memory memory,
 	struct vb2_buffer *vb;
 	int ret;
 
 	/* Ensure that q->num_buffers+num_buffers is below VB2_MAX_FRAME */
 	num_buffers = min_t(unsigned int, num_buffers,
-			    VB2_MAX_FRAME - q->num_buffers);
+			    q->max_num_buffers - q->num_buffers);
 
 	for (buffer = 0; buffer < num_buffers; ++buffer) {
 		/* Allocate vb2 buffer structures */
@@ -816,7 +816,7 @@ int vb2_core_reqbufs(struct vb2_queue *q, enum vb2_memory memory,
 	unsigned plane_sizes[VB2_MAX_PLANES] = { };
 	bool non_coherent_mem = flags & V4L2_MEMORY_FLAG_NON_COHERENT;
 	unsigned int i;
-	int ret;
+	int ret = 0;
 
 	if (q->streaming) {
 		dprintk(q, 1, "streaming active\n");
@@ -860,17 +860,22 @@ int vb2_core_reqbufs(struct vb2_queue *q, enum vb2_memory memory,
 	/*
 	 * Make sure the requested values and current defaults are sane.
 	 */
-	WARN_ON(q->min_buffers_needed > VB2_MAX_FRAME);
 	num_buffers = max_t(unsigned int, *count, q->min_buffers_needed);
-	num_buffers = min_t(unsigned int, num_buffers, VB2_MAX_FRAME);
+	num_buffers = min_t(unsigned int, num_buffers, q->max_num_buffers);
 	memset(q->alloc_devs, 0, sizeof(q->alloc_devs));
 	/*
 	 * Set this now to ensure that drivers see the correct q->memory value
 	 * in the queue_setup op.
 	 */
 	mutex_lock(&q->mmap_lock);
+	if (!q->bufs)
+		q->bufs = kcalloc(q->max_num_buffers, sizeof(*q->bufs), GFP_KERNEL);
+	if (!q->bufs)
+		ret = -ENOMEM;
 	q->memory = memory;
 	mutex_unlock(&q->mmap_lock);
+	if (ret)
+		return ret;
 	set_queue_coherency(q, non_coherent_mem);
 
 	/*
@@ -979,7 +984,7 @@ int vb2_core_create_bufs(struct vb2_queue *q, enum vb2_memory memory,
 	bool no_previous_buffers = !q_num_bufs;
 	int ret = 0;
 
-	if (q_num_bufs == VB2_MAX_FRAME) {
+	if (q->num_buffers == q->max_num_buffers) {
 		dprintk(q, 1, "maximum number of buffers already allocated\n");
 		return -ENOBUFS;
 	}
@@ -996,7 +1001,13 @@ int vb2_core_create_bufs(struct vb2_queue *q, enum vb2_memory memory,
 		 */
 		mutex_lock(&q->mmap_lock);
 		q->memory = memory;
+		if (!q->bufs)
+			q->bufs = kcalloc(q->max_num_buffers, sizeof(*q->bufs), GFP_KERNEL);
+		if (!q->bufs)
+			ret = -ENOMEM;
 		mutex_unlock(&q->mmap_lock);
+		if (ret)
+			return ret;
 		q->waiting_for_buffers = !q->is_output;
 		set_queue_coherency(q, non_coherent_mem);
 	} else {
@@ -1008,7 +1019,7 @@ int vb2_core_create_bufs(struct vb2_queue *q, enum vb2_memory memory,
 			return -EINVAL;
 	}
 
-	num_buffers = min(*count, VB2_MAX_FRAME - q_num_bufs);
+	num_buffers = min(*count, q->max_num_buffers - q_num_bufs);
 
 	if (requested_planes && requested_sizes) {
 		num_planes = requested_planes;
@@ -2466,6 +2477,12 @@ int vb2_core_queue_init(struct vb2_queue *q)
 	/*
 	 * Sanity check
 	 */
+	if (!q->max_num_buffers)
+		q->max_num_buffers = VB2_MAX_FRAME;
+
+	/* The maximum is limited by offset cookie encoding pattern */
+	q->max_num_buffers = min_t(unsigned int, q->max_num_buffers, MAX_BUFFER_INDEX);
+
 	if (WARN_ON(!q)			  ||
 	    WARN_ON(!q->ops)		  ||
 	    WARN_ON(!q->mem_ops)	  ||
@@ -2475,6 +2492,10 @@ int vb2_core_queue_init(struct vb2_queue *q)
 	    WARN_ON(!q->ops->buf_queue))
 		return -EINVAL;
 
+	if (WARN_ON(q->max_num_buffers > MAX_BUFFER_INDEX) ||
+	    WARN_ON(q->min_buffers_needed > q->max_num_buffers))
+		return -EINVAL;
+
 	if (WARN_ON(q->requires_requests && !q->supports_requests))
 		return -EINVAL;
 
@@ -2520,8 +2541,9 @@ void vb2_core_queue_release(struct vb2_queue *q)
 	__vb2_cleanup_fileio(q);
 	__vb2_queue_cancel(q);
 	mutex_lock(&q->mmap_lock);
-	__vb2_queue_free(q, vb2_get_num_buffers(q));
-	q->num_buffers = 0;
+	__vb2_queue_free(q, q->max_num_buffers);
+	kfree(q->bufs);
+	q->bufs = NULL;
 	mutex_unlock(&q->mmap_lock);
 }
 EXPORT_SYMBOL_GPL(vb2_core_queue_release);
@@ -450,9 +450,9 @@ static int __vb2_queue_alloc(struct vb2_queue *q, enum vb2_memory memory,
 	int ret;
 
-	/* Ensure that q->num_buffers+num_buffers is below VB2_MAX_FRAME */
+	/* Ensure that the number of already queue + num_buffers is below q->max_num_buffers */
 	num_buffers = min_t(unsigned int, num_buffers,
-- 
2.39.2


_______________________________________________
Linux-rockchip mailing list
Linux-rockchip@lists.infradead.org
http://lists.infradead.org/mailman/listinfo/linux-rockchip

  parent reply	other threads:[~2023-10-12 11:47 UTC|newest]

Thread overview: 222+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-10-12 11:45 [PATCH v11 00/56] Add DELETE_BUF ioctl Benjamin Gaignard
2023-10-12 11:45 ` Benjamin Gaignard
2023-10-12 11:45 ` Benjamin Gaignard
2023-10-12 11:45 ` [PATCH v11 01/56] media: videobuf2: Rename offset parameter Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45 ` [PATCH v11 02/56] media: videobuf2: Rework offset 'cookie' encoding pattern Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45 ` [PATCH v11 03/56] media: videobuf2: Stop spamming kernel log with all queue counter Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45 ` [PATCH v11 04/56] media: videobuf2: Use vb2_buffer instead of index Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-16  7:34   ` Hans Verkuil
2023-10-16  7:34     ` Hans Verkuil
2023-10-16  7:34     ` Hans Verkuil
2023-10-12 11:45 ` [PATCH v11 05/56] media: videobuf2: Access vb2_queue bufs array through helper functions Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-16  7:50   ` Hans Verkuil
2023-10-16  7:50     ` Hans Verkuil
2023-10-16  7:50     ` Hans Verkuil
2023-10-12 11:45 ` [PATCH v11 06/56] media: videobuf2: Remove duplicated index vs q->num_buffers check Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45 ` [PATCH v11 07/56] media: videobuf2: Add helper to get queue number of buffers Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45 ` [PATCH v11 08/56] media: videobuf2: Use vb2_get_num_buffers() helper Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-16  8:08   ` Hans Verkuil
2023-10-16  8:08     ` Hans Verkuil
2023-10-16  8:08     ` Hans Verkuil
2023-10-12 11:45 ` [PATCH v11 09/56] media: amphion: Use vb2_get_buffer() instead of directly access to buffers array Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-16  8:13   ` Hans Verkuil
2023-10-16  8:13     ` Hans Verkuil
2023-10-16  8:13     ` Hans Verkuil
2023-10-12 11:45 ` [PATCH v11 10/56] media: amphion: Stop direct calls to queue num_buffers field Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45 ` [PATCH v11 11/56] media: mediatek: jpeg: Use vb2_get_buffer() instead of directly access to buffers array Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45 ` [PATCH v11 12/56] media: mediatek: vdec: Remove useless loop Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45 ` [PATCH v11 13/56] media: mediatek: vcodec: Stop direct calls to queue num_buffers field Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:45   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 14/56] media: sti: hva: Use vb2_get_buffer() instead of directly access to buffers array Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 15/56] media: visl: " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 16/56] media: atomisp: " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 12:10   ` Hans de Goede
2023-10-12 12:10     ` Hans de Goede
2023-10-12 12:10     ` Hans de Goede
2023-10-12 11:46 ` [PATCH v11 17/56] media: atomisp: Stop direct calls to queue num_buffers field Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 12:10   ` Hans de Goede
2023-10-12 12:10     ` Hans de Goede
2023-10-12 12:10     ` Hans de Goede
2023-10-12 11:46 ` [PATCH v11 18/56] media: dvb-core: Use vb2_get_buffer() instead of directly access to buffers array Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 19/56] media: dvb-core: Do not initialize twice queue num_buffer field Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 20/56] media: dvb-frontends: rtl2832_srd: Use queue min_buffers_needed field Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 21/56] media: video-i2c: Set min_buffers_needed to 2 Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 22/56] media: pci: cx18: Set correct value to min_buffers_needed field Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 23/56] media: pci: dt3155: Remove useless check Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 24/56] media: pci: netup_unidvb: Remove useless number of buffers check Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 25/56] media: pci: tw68: Stop direct calls to queue num_buffers field Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 26/56] media: pci: tw686x: Set min_buffers_needed to 3 Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 27/56] media: coda: Stop direct calls to queue num_buffers field Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 28/56] media: nxp: " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 29/56] media: renesas: Set min_buffers_needed to 16 Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 30/56] media: ti: Use queue min_buffers_needed field to set the min number of buffers Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 31/56] media: verisilicon: Stop direct calls to queue num_buffers field Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 32/56] media: test-drivers: " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 33/56] media: usb: airspy: Set min_buffers_needed to 8 Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 34/56] media: usb: cx231xx: Set min_buffers_needed to CX231XX_MIN_BUF Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-16  8:20   ` Hans Verkuil
2023-10-16  8:20     ` Hans Verkuil
2023-10-16  8:20     ` Hans Verkuil
2023-10-12 11:46 ` [PATCH v11 35/56] media: usb: hackrf: Set min_buffers_needed to 8 Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 36/56] media: usb: usbtv: Set min_buffers_needed to 2 Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 37/56] media: imx: Stop direct calls to queue num_buffers field Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 38/56] media: meson: vdec: " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 39/56] touchscreen: sur40: " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-16  8:22   ` Hans Verkuil
2023-10-16  8:22     ` Hans Verkuil
2023-10-16  8:22     ` Hans Verkuil
2023-10-12 11:46 ` [PATCH v11 40/56] sample: v4l: " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-16  8:23   ` Hans Verkuil
2023-10-16  8:23     ` Hans Verkuil
2023-10-16  8:23     ` Hans Verkuil
2023-10-16 10:17     ` Hans Verkuil
2023-10-12 11:46 ` [PATCH v11 41/56] media: cedrus: " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-17  8:54   ` Paul Kocialkowski
2023-10-17  8:54     ` Paul Kocialkowski
2023-10-17  8:54     ` Paul Kocialkowski
2023-10-17  9:59     ` Benjamin Gaignard
2023-10-17  9:59       ` Benjamin Gaignard
2023-10-17  9:59       ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 42/56] media: nuvoton: " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` Benjamin Gaignard [this message]
2023-10-12 11:46   ` [PATCH v11 43/56] media: videobuf2: Be more flexible on the number of queue stored buffers Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 44/56] media: core: Report the maximum possible number of buffers for the queue Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-16 10:27   ` Hans Verkuil
2023-10-16 10:27     ` Hans Verkuil
2023-10-16 10:27     ` Hans Verkuil
2023-10-12 11:46 ` [PATCH v11 45/56] media: test-drivers: vivid: Increase max supported buffers for capture queues Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-16 10:32   ` Hans Verkuil
2023-10-16 10:32     ` Hans Verkuil
2023-10-16 14:20     ` Benjamin Gaignard
2023-10-16 14:20       ` Benjamin Gaignard
2023-10-16 14:20       ` Benjamin Gaignard
2023-10-16 14:33       ` Hans Verkuil
2023-10-16 14:33         ` Hans Verkuil
2023-10-16 14:33         ` Hans Verkuil
2023-10-12 11:46 ` [PATCH v11 46/56] media: test-drivers: vicodec: Increase max supported capture queue buffers Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 47/56] media: verisilicon: Refactor postprocessor to store more buffers Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 48/56] media: verisilicon: Store chroma and motion vectors offset Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 49/56] media: verisilicon: g2: Use common helpers to compute chroma and mv offsets Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 50/56] media: verisilicon: vp9: Allow to change resolution while streaming Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 51/56] media: core: Rework how create_buf index returned value is computed Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 52/56] media: core: Add bitmap manage bufs array entries Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 53/56] media: core: Free range of buffers Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 54/56] media: v4l2: Add DELETE_BUFS ioctl Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 55/56] media: v4l2: Add mem2mem helpers for " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46 ` [PATCH v11 56/56] media: test-drivers: Use helper " Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-12 11:46   ` Benjamin Gaignard
2023-10-16 10:39 ` [PATCH v11 00/56] Add DELETE_BUF ioctl Hans Verkuil
2023-10-16 10:39   ` Hans Verkuil
2023-10-16 10:39   ` Hans Verkuil
2023-10-16 12:03   ` Benjamin Gaignard
2023-10-16 12:03     ` Benjamin Gaignard
2023-10-16 12:03     ` Benjamin Gaignard

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20231012114642.19040-44-benjamin.gaignard@collabora.com \
    --to=benjamin.gaignard@collabora.com \
    --cc=ezequiel@vanguardiasur.com.ar \
    --cc=gregkh@linuxfoundation.org \
    --cc=hverkuil-cisco@xs4all.nl \
    --cc=kernel@collabora.com \
    --cc=linux-arm-kernel@lists.infradead.org \
    --cc=linux-arm-msm@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-media@vger.kernel.org \
    --cc=linux-mediatek@lists.infradead.org \
    --cc=linux-rockchip@lists.infradead.org \
    --cc=linux-staging@lists.linux.dev \
    --cc=m.szyprowski@samsung.com \
    --cc=mchehab@kernel.org \
    --cc=ming.qian@nxp.com \
    --cc=nicolas.dufresne@collabora.com \
    --cc=p.zabel@pengutronix.de \
    --cc=tfiga@chromium.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.